@@ -39,7 +39,6 @@
 #include <KSharedConfig>
 
 #include "ddcutilbrightness.h"
-#include "upowersuspendjob.h"
 #include "login1suspendjob.h"
 
 #define HELPER_ID "org.kde.powerdevil.backlighthelper"
@@ -179,24 +178,16 @@ void PowerDevilUPowerBackend::initWithBrightness(bool screenBrightnessAvailable)
     // Capabilities
     setCapabilities(SignalResumeFromSuspend);
 
-    // devices
-    enumerateDevices();
-
-    connect(m_upowerInterface, &OrgFreedesktopUPowerInterface::Changed, this, &PowerDevilUPowerBackend::slotPropertyChanged);
-    // for UPower >= 0.99.0, missing Changed() signal
     QDBusConnection::systemBus().connect(UPOWER_SERVICE, UPOWER_PATH, "org.freedesktop.DBus.Properties", "PropertiesChanged", this,
                                          SLOT(onPropertiesChanged(QString,QVariantMap,QStringList)));
 
-    connect(m_upowerInterface, SIGNAL(DeviceAdded(QString)), this, SLOT(slotDeviceAdded(QString)));
-    connect(m_upowerInterface, SIGNAL(DeviceRemoved(QString)), this, SLOT(slotDeviceRemoved(QString)));
-    // for UPower >= 0.99.0, changed signature :o/
     QDBusConnection::systemBus().connect(UPOWER_SERVICE, UPOWER_PATH, UPOWER_IFACE, "DeviceAdded",
                                          this, SLOT(slotDeviceAdded(QDBusObjectPath)));
     QDBusConnection::systemBus().connect(UPOWER_SERVICE, UPOWER_PATH, UPOWER_IFACE, "DeviceRemoved",
                                          this, SLOT(slotDeviceRemoved(QDBusObjectPath)));
 
-    connect(m_upowerInterface, &OrgFreedesktopUPowerInterface::DeviceChanged, this, &PowerDevilUPowerBackend::slotDeviceChanged);
-    // for UPower >= 0.99.0, see slotDeviceAdded(const QString & device)
+    // devices
+    enumerateDevices();
 
     // Brightness Controls available
     BrightnessControlsList controls;
@@ -246,30 +237,9 @@ void PowerDevilUPowerBackend::initWithBrightness(bool screenBrightnessAvailable)
             supported |= SuspendThenHibernate;
     }
 
-    /* There's a chance we're using ConsoleKit rather than ConsoleKit2 as the
-     * m_login1Interface, so check if we can suspend/hibernate with UPower < 0.99 */
-    if (supported == UnknownSuspendMethod) {
-        if (m_upowerInterface->canSuspend() && m_upowerInterface->SuspendAllowed()) {
-            qCDebug(POWERDEVIL) << "Can suspend";
-            supported |= ToRam;
-        }
-
-        if (m_upowerInterface->canHibernate() && m_upowerInterface->HibernateAllowed()) {
-            qCDebug(POWERDEVIL) << "Can hibernate";
-            supported |= ToDisk;
-        }
-
-        if (supported != UnknownSuspendMethod) {
-            m_useUPowerSuspend = true;
-        }
-    }
-
     // "resuming" signal
-    if (m_login1Interface && !m_useUPowerSuspend) {
+    if (m_login1Interface) {
         connect(m_login1Interface.data(), SIGNAL(PrepareForSleep(bool)), this, SLOT(slotLogin1PrepareForSleep(bool)));
-    } else {
-        connect(m_upowerInterface, &OrgFreedesktopUPowerInterface::Sleeping, this, &PowerDevilUPowerBackend::aboutToSuspend);
-        connect(m_upowerInterface, &OrgFreedesktopUPowerInterface::Resuming, this, &PowerDevilUPowerBackend::resumeFromSuspend);
     }
 
     // battery
@@ -459,11 +429,10 @@ void PowerDevilUPowerBackend::onKeyboardBrightnessChanged(int value)
 
 KJob* PowerDevilUPowerBackend::suspend(PowerDevil::BackendInterface::SuspendMethod method)
 {
-    if (m_login1Interface && !m_useUPowerSuspend) {
+    if (m_login1Interface) {
         return new Login1SuspendJob(m_login1Interface.data(), method, supportedSuspendMethods());
-    } else {
-        return new UPowerSuspendJob(m_upowerInterface, method, supportedSuspendMethods());
     }
+    return nullptr;
 }
 
 void PowerDevilUPowerBackend::enumerateDevices()
@@ -475,6 +444,9 @@ void PowerDevilUPowerBackend::enumerateDevices()
 
     const QList<QDBusObjectPath> deviceList = m_upowerInterface->EnumerateDevices();
     for (const QDBusObjectPath & device : deviceList) {
+        if (m_devices.contains(device.path())) {
+            continue;
+        }
         addDevice(device.path());
     }
 
@@ -500,91 +472,65 @@ void PowerDevilUPowerBackend::addDevice(const QString & device)
             new OrgFreedesktopUPowerDeviceInterface(UPOWER_SERVICE, device, QDBusConnection::systemBus(), this);
     m_devices.insert(device, upowerDevice);
 
-    // for UPower >= 0.99.0 which doesn't emit the DeviceChanged(QString) signal
     QDBusConnection::systemBus().connect(UPOWER_SERVICE, device, "org.freedesktop.DBus.Properties", "PropertiesChanged", this,
                                          SLOT(onDevicePropertiesChanged(QString,QVariantMap,QStringList)));
 }
 
-void PowerDevilUPowerBackend::slotDeviceAdded(const QString & device)
+void PowerDevilUPowerBackend::slotDeviceAdded(const QDBusObjectPath &path)
 {
-    addDevice(device);
+    addDevice(path.path());
     updateDeviceProps();
 }
 
-void PowerDevilUPowerBackend::slotDeviceRemoved(const QString & device)
+void PowerDevilUPowerBackend::slotDeviceRemoved(const QDBusObjectPath &path)
 {
-    OrgFreedesktopUPowerDeviceInterface * upowerDevice = m_devices.take(device);
+    OrgFreedesktopUPowerDeviceInterface * upowerDevice = m_devices.take(path.path());
 
     delete upowerDevice;
 
     updateDeviceProps();
 }
 
-void PowerDevilUPowerBackend::slotDeviceAdded(const QDBusObjectPath &path)
-{
-    slotDeviceAdded(path.path());
-}
-
-void PowerDevilUPowerBackend::slotDeviceRemoved(const QDBusObjectPath &path)
-{
-    slotDeviceRemoved(path.path());
-}
-
-void PowerDevilUPowerBackend::slotDeviceChanged(const QString & /*device*/)
-{
-    updateDeviceProps();
-}
-
 void PowerDevilUPowerBackend::updateDeviceProps()
 {
-    qlonglong remainingTime = 0;
+    double energyTotal = 0.0;
+    double energyRateTotal = 0.0;
+    double energyFullTotal = 0.0;
 
     if (m_displayDevice && m_displayDevice->isPresent()) {
         const uint state = m_displayDevice->state();
-        if (state == 1) // charging
-            remainingTime = m_displayDevice->timeToFull();
-        else if (state == 2) //discharging
-            remainingTime = m_displayDevice->timeToEmpty();
-    } else {
-        qreal energyTotal = 0.0;
-        qreal energyRateTotal = 0.0;
-        qreal energyFullTotal = 0.0;
-        uint stateTotal = 0;
+        energyTotal = m_displayDevice->energy();
+        energyFullTotal = m_displayDevice->energyFull();
 
+        if (state == 1) { // charging
+            energyRateTotal = m_displayDevice->energyRate();
+        } else if (state == 2) { //discharging
+            energyRateTotal = -1.0 * m_displayDevice->energyRate();
+        }
+    } else {
         for (const OrgFreedesktopUPowerDeviceInterface * upowerDevice : qAsConst(m_devices)) {
             const uint type = upowerDevice->type();
             if (( type == 2 || type == 3) && upowerDevice->powerSupply()) {
                 const uint state = upowerDevice->state();
                 energyFullTotal += upowerDevice->energyFull();
                 energyTotal += upowerDevice->energy();
-                energyRateTotal += upowerDevice->energyRate();
 
-                if (state == 1) { // total is charging
-                    stateTotal = 1;
-                } else if (state == 2 && stateTotal != 1) { // total is discharging
-                    stateTotal = 2;
-                } else if (state == 4 && stateTotal != 0) { // total is fully-charged
-                    stateTotal = 4;
+                if (state == 4) { // fully charged
+                    continue;
                 }
 
                 if (state == 1) { // charging
-                    remainingTime += upowerDevice->timeToFull();
+                    energyRateTotal += upowerDevice->energyRate();
                 } else if (state == 2) { // discharging
-                    remainingTime += upowerDevice->timeToEmpty();
+                    energyRateTotal -= upowerDevice->energyRate();
                 }
             }
         }
-
-        if (energyRateTotal > 0) {
-            if (stateTotal == 1) { // charging
-                remainingTime = 3600 * ((energyFullTotal - energyTotal) / energyRateTotal);
-            } else if (stateTotal == 2) { // discharging
-                remainingTime = 3600 * (energyTotal / energyRateTotal);
-            }
-        }
     }
 
-    setBatteryRemainingTime(remainingTime * 1000);
+    setBatteryEnergy(energyTotal);
+    setBatteryEnergyFull(energyFullTotal);
+    setBatteryRate(energyRateTotal);
 }
 
 void PowerDevilUPowerBackend::slotPropertyChanged()
