@@ -27,14 +27,13 @@
 #include <QScopedPointer>
 #include <QTimer>
 
-#ifdef HAVE_XCB
+#if HAVE_XCB
 #include <xcb/xcb.h>
 #endif
 
 namespace PowerDevil
 {
-
-class KWinKScreenHelperEffect : public QObject, public QAbstractNativeEventFilter
+class Q_DECL_EXPORT KWinKScreenHelperEffect : public QObject, public QAbstractNativeEventFilter
 {
     Q_OBJECT
 
@@ -74,7 +73,7 @@ private:
 
     QTimer m_abortTimer;
 
-#ifdef HAVE_XCB
+#if HAVE_XCB
     xcb_atom_t m_atom = 0;
 #endif
 
