@@ -39,18 +39,6 @@ public:
     explicit BackendInterface(QObject* parent = nullptr);
     ~BackendInterface() override;
 
-    /**
-     * This enum type defines the different states of the system battery.
-     *
-     * - NoBatteryState: No battery available
-     * - Normal: The battery is at its normal charge level
-     * - Warning: The battery is at its warning charge level
-     * - Low: The battery is at its low charge level
-     * - Critical: The battery is at its critical charge level
-     */
-    enum BatteryState{ NoBatteryState, Normal, Warning, Low, Critical };
-    Q_ENUM(BatteryState)
-
     /**
      * This enum type defines the different states of the AC adapter.
      *
@@ -128,14 +116,6 @@ public:
      */
     Capabilities capabilities() const;
 
-    /**
-     * Retrieves the current state of the system battery.
-     *
-     * @return the current battery state
-     * @see PowerDevil::BackendInterface::BatteryState
-     */
-    BatteryState batteryState() const;
-
     /**
      * Retrieves the current estimated remaining time of the system batteries
      *
@@ -252,14 +232,6 @@ Q_SIGNALS:
      */
     void acAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState newState);
 
-    /**
-     * This signal is emitted when the system battery state changed.
-     *
-     * @param newState the new state of the system battery, it's one of the
-     * type @see PowerDevil::BackendInterface::BatteryState
-     */
-    void batteryStateChanged(PowerDevil::BackendInterface::BatteryState newState);
-
     /**
      * This signal is emitted when a button has been pressed.
      *
@@ -326,9 +298,10 @@ protected:
     void setCapabilities(Capabilities capabilities);
 
     void onBrightnessChanged(BrightnessControlType device, int value, int valueMax);
-    void setBatteryRemainingTime(qulonglong time);
+    void setBatteryEnergy(double energy);
+    void setBatteryEnergyFull(double energy);
+    void setBatteryRate(double rate);
     void setButtonPressed(PowerDevil::BackendInterface::ButtonType type);
-    void setBatteryState(PowerDevil::BackendInterface::BatteryState state);
     void setAcAdapterState(PowerDevil::BackendInterface::AcAdapterState state);
 
     void setCapacityForBattery(const QString &batteryId, uint percent);
