@@ -46,12 +46,10 @@
 #include <KSharedConfig>
 #include <KLocalizedString>
 
-K_PLUGIN_FACTORY(PowerDevilActivitiesKCMFactory,
-                 registerPlugin<ActivityPage>();
-                )
+K_PLUGIN_CLASS_WITH_JSON(ActivityPage, "kcm_powerdevilactivitiesconfig.json")
 
 ActivityPage::ActivityPage(QWidget *parent, const QVariantList &args)
-    : KCModule(nullptr, parent, args)
+    : KCModule(parent, args)
     , m_activityConsumer(new KActivities::Consumer(this))
 {
     setButtons(Apply | Help);
